/* This example requires Tailwind CSS v2.0+ */
import React, { Fragment } from 'react';
import { Disclosure, Menu, Transition } from '@headlessui/react'
import {  MenuIcon, XIcon, LoginIcon  } from '@heroicons/react/outline'
import { SparklesIcon, BellIcon } from '@heroicons/react/solid';
import PropTypes from 'prop-types';

const classNames = (...classes) => {
  return classes.filter(Boolean).join(' ')
}

const MarketingHeader = ({ logo, logoMark, user,  currentUser, logOut }) => {
  return (
    <Disclosure as="nav" className="bg-white shadow">
      {({ open }) => (
        <>
          <div>
            <div className="flex justify-between h-16">
              <div className="flex">
                <div className="flex-shrink-0 flex items-center pl-2">
                  <img
                    className="block lg:hidden h-8 w-auto"
                    src={logoMark.url}
                    alt=""
                  />
                  <img
                    className="hidden lg:block h-8 w-auto"
                    src={logo.url}
                    alt=""
                  />
                </div>
              </div>
              <div className="space-x-4 hidden md:block pt-4">
                {currentUser ?
                <div className="absolute inset-y-0 right-0 flex items-center pr-2 sm:static sm:inset-auto sm:ml-6 sm:pr-0 mr-3">
                  <button className="ml-auto flex-shrink-0 bg-white p-2 rounded-full text-gray-400 hover:text-gray-500 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                    <span className="sr-only">View notifications</span>
                    <BellIcon className="h-6 w-6" aria-hidden="true" />
                  </button>


                {/* Profile dropdown */}
                  <Menu as="div" className="ml-3 relative">
                    {({ open }) => (
                      <>
                        <div>
                          <Menu.Button className="bg-gray-800 flex text-sm rounded-full focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-gray-800 focus:ring-white">
                            <span className="sr-only">Open user menu</span>
                            <img
                              className="h-8 w-8 rounded-full"
                              src={user.imagesUrl}
                              alt=""
                            />
                          </Menu.Button>
                        </div>
                        <Transition
                          show={open}
                          as={Fragment}
                          enter="transition ease-out duration-100"
                          enterFrom="transform opacity-0 scale-95"
                          enterTo="transform opacity-100 scale-100"
                          leave="transition ease-in duration-75"
                          leaveFrom="transform opacity-100 scale-100"
                          leaveTo="transform opacity-0 scale-95"
                        >
                          <Menu.Items
                            static
                            className="origin-top-right absolute right-0 mt-2 w-48 rounded-md shadow-lg py-1 bg-white ring-1 ring-black ring-opacity-5 focus:outline-none"
                          >
                            <Menu.Item>
                              {({ active }) => (
                                <a
                                  href="#"
                                  onClick={logOut}
                                  className={classNames(
                                    active ? 'bg-gray-100' : '',
                                    'block px-4 py-2 text-sm text-gray-700'
                                  )}
                                >
                                  Sign out
                                </a>
                              )}
                            </Menu.Item>
                          </Menu.Items>
                        </Transition>
                      </>
                    )}
                  </Menu>
                </div>
                :
                <div className="mr-3">
                  <button
                    type="button"
                    className="relative inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md text-white bg-indigo-500 shadow-sm hover:bg-indigo-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    <SparklesIcon className="-ml-1 mr-2 h-5 w-5" aria-hidden="true" />
                    <span>Become A Partner</span>
                  </button>
                  <button
                    type="button"
                    className="relative inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md text-indigo-500 bg-white hover:text-indigo-600 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-gray-50"
                  >
                    <LoginIcon className="-ml-1 mr-2 h-5 w-5" aria-hidden="true" />
                    <span>Login/Register</span>
                  </button>
                </div>
                }
              </div>
              <div className="-mr-2 flex items-center sm:hidden px-4">
                {/* Mobile menu button */}
                <Disclosure.Button className="inline-flex items-center justify-center p-2 rounded-md text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-indigo-500">
                  <span className="sr-only">Open main menu</span>
                  {open ? (
                    <XIcon className="block h-6 w-6" aria-hidden="true" />
                  ) : (
                    <MenuIcon className="block h-6 w-6" aria-hidden="true" />
                  )}
                </Disclosure.Button>
              </div>
            </div>
          </div>

          <Disclosure.Panel className="sm:hidden">
            <div className="pt-2 pb-3 space-y-1 shadow rounded-md">
              {currentUser ?
              <>
                <div className="flex items-center px-4 sm:px-6">
                  <div className="flex-shrink-0">
                      <img
                          className="h-10 w-10 rounded-full"
                          src={user.imagesUrl}
                          alt=""
                      />
                  </div>
                  <div className="ml-3">
                      {user.firstName && user.lastName && <div className="text-base font-medium text-gray-800">{`${user.firstName} ${user.lastName}`}</div>}
                      {user.email && <div className="text-sm font-medium text-gray-500">{user.email}</div>}
                  </div>
                  <button className="ml-auto flex-shrink-0 bg-white p-1 rounded-full text-gray-400 hover:text-gray-500 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                      <span className="sr-only">View notifications</span>
                      <BellIcon className="h-6 w-6" aria-hidden="true" />
                  </button>
                </div>
                <div className="mt-3 space-y-1">
                    <a
                        href="#"
                        className="block px-4 py-2 text-base font-medium text-gray-500 hover:text-gray-800 hover:bg-gray-100 sm:px-6"
                        onClick={logOut}
                    >
                        Sign out
                    </a>
                </div>
              </>
              :
              <>
                <a
                  href="#"
                  className="text-black block pl-3 pr-4 py-2 text-base font-medium hover:text-indigo-600"
                >
                  Become A Partner
                </a>
                <a
                  href="/signin"
                  className="bg-indigo-50 border-indigo-500 text-indigo-500 border-transparent hover:bg-indigo-100 hover:border-indigo-300 hover:text-indigo-600 block pl-3 pr-4 py-2 border-l-4 text-base font-medium"
                >
                  Login/Register
                </a>
              </>
              }
            </div>
          </Disclosure.Panel>
        </>
      )}
    </Disclosure>
  )
}



MarketingHeader.propTypes = {
  logo:PropTypes.shape({
    url: PropTypes.string.isRequired
  }).isRequired,
  logoMark:PropTypes.shape({
    url: PropTypes.string.isRequired
  }).isRequired,
  user:PropTypes.shape({
    firstName: PropTypes.string,
    lastName: PropTypes.string,
    email: PropTypes.string
  }),
  currentUser:PropTypes.shape({
    firebaseId: PropTypes.string,
  }),
  logOut:PropTypes.func
};
export default MarketingHeader;
